if (!global.Intl) {
  // No `Intl`, so use and load the polyfill.
  global.Intl = require('intl');
}

var React = require('react');
var ReactIntl = require('react-intl');
var IntlProvider = ReactIntl.IntlProvider;
var FormattedMessage = ReactIntl.FormattedMessage;
var LinkedStateMixin = require('react-addons-linked-state-mixin');
var Textarea = require('react-textarea-autosize').default;

/**
 * @class TextBlockComponent
 *
 * This class will recursively interpret a textblock, thus it might hold
 * some instances of itself.
 *
 * @member {String} prefix The prefix for all control names
 * @member {String} proto The proto in use (determines if we should do index or not)
 * @member {Object} block A Textblock.
 */

var TextBlockEditor = React.createClass({
  displayName: 'TextBlockEditor',
  mixins: [LinkedStateMixin],

  getInitialState: function () {
    if (this.props.block) {
      return this.props.block;
    } else {
      return {};
    }
  },

  render: function () {
    if (this.state.format !== 'pragma') {
      var vlink = 'source';
      return React.createElement(
        'fieldset',
        null,
        React.createElement(Textarea, { name: this.props.prefix + '[source]',
          className: 'pure-input-1', placeholder: 'Posting',
          valueLink: this.linkState(vlink) }),
        React.createElement(
          'select',
          { size: '1', name: this.props.prefix + '[format]',
            valueLink: this.linkState('format') },
          React.createElement(
            'option',
            { value: 'html' },
            'HTML'
          ),
          React.createElement(
            'option',
            { value: 'markdown' },
            'Markdown'
          )
        )
      );
    }
  }
});

var IndexBlockEditor = React.createClass({
  displayName: 'IndexBlockEditor',

  mixins: [LinkedStateMixin],

  getInitialState: function () {
    if (this.props.block) {
      return this.props.block;
    } else {
      return {};
    }
  },

  render: function () {
    if (this.state.format === 'pragma') {
      return React.createElement(
        'fieldset',
        null,
        React.createElement('input', { type: 'hidden', value: 'pragma', name: this.props.prefix + '[format]' }),
        React.createElement(
          'select',
          { name: this.props.prefix + '[query]', size: '1',
            valueLink: this.linkState('query') },
          React.createElement(
            'option',
            { value: 'child' },
            'Query Children (Including this page and all descendents)'
          ),
          React.createElement(
            'option',
            { value: 'parents' },
            'Query Parent Pages'
          ),
          React.createElement(
            'option',
            { value: 'dir' },
            'Directory (Only first level children)'
          )
        ),
        React.createElement(
          'select',
          { name: this.props.prefix + '[sort]', size: '1',
            valueLink: this.linkState('sort') },
          React.createElement(
            'option',
            { value: 'path' },
            'In path order'
          ),
          React.createElement(
            'option',
            { value: 'changed' },
            'By most recently changed'
          ),
          React.createElement(
            'option',
            { value: 'created' },
            'By most recently created'
          )
        ),
        React.createElement(
          'div',
          { className: 'pure-g' },
          React.createElement(
            'div',
            { className: 'pure-u-1-2' },
            React.createElement(
              'label',
              { htmlFor: this.props.prefix + '[navbar]', className: 'pure-checkbox' },
              React.createElement('input', { type: 'checkbox', value: 'true', name: this.props.prefix + '[navbar]',
                checkedLink: this.linkState('navbar') }),
              React.createElement(FormattedMessage, { id: 'NAVBAR', defaultMessage: 'Navbar' })
            ),
            React.createElement(
              'label',
              { htmlFor: this.props.prefix + '[pagination]', className: 'pure-checkbox' },
              React.createElement('input', { type: 'checkbox', value: 'true', name: this.props.prefix + '[pagination]',
                checkedLink: this.linkState('pagination') }),
              React.createElement(FormattedMessage, { id: 'PAGINATED', defaultMessage: 'Paginated' })
            )
          ),
          React.createElement(
            'div',
            { className: 'pure-u-1-2' },
            React.createElement(
              'label',
              { htmlFor: this.props.prefix + '[navbar]', className: 'pure-checkbox' },
              React.createElement('input', { type: 'checkbox', value: 'true', name: this.props.prefix + '[monthFacet]',
                checkedLink: this.linkState('monthFacet') }),
              React.createElement(FormattedMessage, { id: 'FACETED_BY_MONTH', defaultMessage: 'Faceted By Month' })
            ),
            React.createElement(
              'label',
              { htmlFor: this.props.prefix + '[navbar]', className: 'pure-checkbox' },
              React.createElement('input', { type: 'checkbox', value: 'true', name: this.props.prefix + '[tagFacet]',
                checkedLink: this.linkState('tagFacet') }),
              React.createElement(FormattedMessage, { id: 'FACETED_BY_TAG', defaultMessage: 'Faceted By Tag' })
            )
          )
        ),
        React.createElement(
          'select',
          { name: this.props.prefix + '[partial]', size: '1', valueLink: this.linkState('partial') },
          React.createElement(
            'option',
            { value: 'card' },
            'Card'
          ),
          React.createElement(
            'option',
            { value: 'list' },
            'List'
          ),
          React.createElement(
            'option',
            { value: 'grid' },
            'Grid'
          )
        )
      );
    }
  }
});

function mapBlock(block, i, prefix) {
  if (block.format === 'pragma') {
    return React.createElement(IndexBlockEditor, { key: 'b_' + i,
      prefix: prefix + '[blocks][' + i + ']',
      block: block, child: 'true' });
  } else {
    return React.createElement(TextBlockEditor, { key: 'b_' + i,
      prefix: prefix + '[blocks][' + i + ']',
      block: block, child: 'true' });
  }
}

var TextBlockComponent = React.createClass({
  displayName: 'TextBlockComponent',

  mixins: [LinkedStateMixin],

  getInitialState: function () {
    if (this.props.block) {
      return this.props.block;
    } else {
      return {};
    }
  },

  addText: function (e) {
    e.preventDefault();
    var blocks;
    if (this.state.format === 'section') {
      blocks = this.state.blocks;
    } else {
      blocks = [this.state];
    }
    blocks.push({ format: 'html', source: '' });
    this.setState({ blocks: blocks,
      format: 'section' });
  },

  addQuery: function (e) {
    e.preventDefault();
    var blocks;
    if (this.state.format === 'section') {
      blocks = this.state.blocks;
    } else {
      blocks = [this.state];
    }
    blocks.push({ query: "parents",
      format: "pragma" });
    this.setState({ blocks: blocks,
      format: 'section' });
  },

  render: function () {
    var buttons;
    if (this.props.proto === 'index') {
      buttons = React.createElement(
        'div',
        { className: 'pure-g-r' },
        React.createElement(
          'button',
          { onClick: this.addText, className: 'pure-button', id: 'addText' },
          'Add Text Section'
        ),
        React.createElement(
          'button',
          { onClick: this.addQuery, className: 'pure-button', id: 'addQuery' },
          'Add Query Section'
        )
      );
    } else {
      buttons = React.createElement(
        'div',
        { className: 'pure-g-r' },
        React.createElement(
          'button',
          { onClick: this.addText, className: 'pure-button', id: 'addText' },
          'Add Text Section'
        )
      );
    }

    if (this.state.format === 'section') {
      var self = this;
      var blocks = this.state.blocks.map(function (block, i) {
        var outBlock;
        outBlock = mapBlock(block, i, self.props.prefix);
        return React.createElement(
          'div',
          { key: i, className: 'textblockbox' },
          outBlock
        );
      });
      return React.createElement(
        IntlProvider,
        { messages: this.props.messages, locale: 'en' },
        React.createElement(
          'fieldset',
          null,
          React.createElement('input', { type: 'hidden', value: 'section', name: this.props.prefix + '[format]',
            id: this.props.prefix + '[format]' }),
          blocks,
          buttons
        )
      );
    } else {
      var block;
      if (this.state.format === 'pragma') {
        block = React.createElement(IndexBlockEditor, {
          prefix: this.props.prefix,
          block: this.state, child: 'false' });
      } else {
        block = React.createElement(TextBlockEditor, {
          prefix: this.props.prefix,
          block: this.state, child: 'false' });
      }
      return React.createElement(
        IntlProvider,
        { messages: this.props.messages, locale: 'en' },
        React.createElement(
          'fieldset',
          null,
          block,
          buttons
        )
      );
    }
  }
});

exports.TextBlockComponent = TextBlockComponent;